@@ -94,13 +94,8 @@ class BaseEntertainer(Hookable):
         if isinstance(message, BouncedUnprovideMessage): 
             #  We are responsible To Shut ourselfves down when Arkitekt Tells us t
             assert message.data.provision is not None, "Received Cancellation with no reference to kill" 
-            self.unentertain(message, from_arkitekt=True)
+            self.unentertain(message)
 
-        if isinstance(message, BouncedProvideMessage): 
-            #  We are responsible To Shut ourselfves down when Arkitekt Tells us t
-            assert message.data.template is not None, "Received Cancellation with no reference to kill" 
-            logger.info("Arkitekt demands a New Actor for us")
-            self.entertain(message, from_arkitekt=True)
 
         if isinstance(message, BouncedForwardedReserveMessage):
             logger.info("Arkitekt demands a New Reservation from us")
