@@ -171,7 +171,7 @@ class BasePostman(Hookable):
         
 
 
-    async def unassign(self, assignation: str, on_progress=None, bounced=None) -> UnassignDoneMessage:
+    async def unassign(self, assignation: str, on_progress=None, bounced=None, persist=True) -> UnassignDoneMessage:
         """ Takes a previously assigned reference to an assignation and cancel the assignation
 
         Args:
@@ -198,7 +198,7 @@ class BasePostman(Hookable):
             self.unassignment_progress_functions[unassign_reference] = on_progress
             with_progress = True
 
-        unassign = build_unassign_messsage(unassign_reference,assignation, with_progress=with_progress, bounced=bounced)
+        unassign = build_unassign_messsage(unassign_reference,assignation, with_progress=with_progress, bounced=bounced, persist=persist)
 
 
         await self.forward(unassign)
@@ -367,7 +367,7 @@ class BasePostman(Hookable):
             del self.assignment_stream_queues[assign_reference]
             try:
                 print(self)
-                await self.unassign(assign_reference, bounced=bounced)
+                await self.unassign(assign_reference, bounced=bounced, persist=persist)
             except:
                 console.print_exception()
             raise e
\ No newline at end of file
